﻿using BlackBerry.Workspaces.Enums;
using BlackBerry.Workspaces.Json;
using System;
using System.Collections.Generic;

namespace BlackBerry.Workspaces.Examples
{
    /// <summary>
    /// Examples of uploading a file to a workspace
    /// </summary>

    public class UploadFilesExample
    {
        private ApiSession apiSession;

        /// <summary>
        /// Creates an instances of the UploadFilesExample class
        /// </summary>
        /// <param name="apiSession">
        /// An ApiSession instance to be used.
        /// </param>
        public UploadFilesExample(ApiSession apiSession)
        {
            this.apiSession = apiSession;
        }
        /// <summary>
        /// UploadDocument
        ///</summary>
        public UploadResult UploadDocument(string localPath, string filename, HashSet<string> userRecipients, HashSet<string> ADGroupsRecipients, HashSet<string> listRecipients)
        {
            // START SNIPPET: devGuide17
            #region devGuide17

            // Get an instance of UploadManager
            UploadManager uploadManager = apiSession.GetUploadManager();

            // Create a new SubmitDocumentSdsJson JSON
            SubmitDocumentSdsJson uploadInfo = new SubmitDocumentSdsJson
            {
                // A call to generate a guid for the document and assign it to DocumentGuids
                DocumentGuids = new HashSet<string> { uploadManager.GetNewGuidForDocument()
                },
                // Create a new permission JSON
                Permission = new PermissionFromUserJson
                {
                    Copy = true,
                    Download = true,
                    DownloadOriginal = false,
                    ExpirationDate = DateTime.Now
                },
                UserRecipients = userRecipients,
                ActiveDirectoryGroupsRecipients = ADGroupsRecipients,
                ListRecipients = listRecipients,
                WhoCanView = WhoCanView.RECEIPIENTS_ONLY
            };
            // A call to the UploadDocument
            UploadResult uploadResult =
                uploadManager.UploadDocument(uploadInfo, localPath, null, filename, null);

            #endregion
            // END SNIPPET: devGuide17
            return uploadResult;
        }
        /// <summary>
        /// UploadDocumentToRoom
        ///</summary>
        public UploadResult UploadDocumentToRoom(int roomId, string destinationFileName, string filename, string folder, List<string> groups, List<string> domains)
        {
            // START SNIPPET: devGuide16
            #region devGuide16

            // Get an instance of UploadManager
            UploadManager uploadManager = apiSession.GetUploadManager();

            // Create a new SubmitDocumentsVdrJson JSON
            SubmitDocumentsVdrJson uploadInfo = new SubmitDocumentsVdrJson
            {
                OpenForAllRoom = false,
                Recipients = new RoomRecipientsJson
                {
                    Groups = groups,
                    Domains = domains,
                },
                Folder = folder,
                TagValueList = null,
                DeviceType = DeviceType.SYNC
            };

            // A call to the UploadDocumentToRoom
            UploadResult uploadResult = uploadManager.UploadDocumentToRoom(uploadInfo,
                roomId, destinationFileName, filename, null);

            #endregion
            // END SNIPPET: devGuide16
            return uploadResult;
        }
    }
}
